﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

using Infragistics.Olap;
using Infragistics.Olap.FlatData;
using System.Collections;

using SampleDataGeneratorNS;

namespace Wpf_xamPivotGrid_flatData
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();    

            Loaded += new RoutedEventHandler(DrillDown_Loaded);
        }

        void DrillDown_Loaded(object sender, RoutedEventArgs e)
        {
            IEnumerable sampleData = SampleDataGenerator.GenerateSales(500);  

            FlatDataSource flatDataSource = new FlatDataSource()
            {
                //Data is the IEnumerable to be used as a source
                ItemsSource = sampleData,
                Cube = DataSourceBase.GenerateInitialCube("Sale"),
                Rows = DataSourceBase.GenerateInitialItems("[Date]"),
                Columns = DataSourceBase.GenerateInitialItems("[City]"),
                Measures = DataSourceBase.GenerateInitialItems("AmountOfSale, Price, NumberOfUnits")
            };

            HierarchyDescriptor<Sale> sellerHierarchy = new HierarchyDescriptor<Sale>(p => p.Seller);
            sellerHierarchy.AddLevel(p => "All Sellers", "All Sellers");
            sellerHierarchy.AddLevel(p => p.Seller.Name, "Seller Name");
            flatDataSource.AddHierarchyDescriptor(sellerHierarchy);

            HierarchyDescriptor<Sale> productHierarchy = new HierarchyDescriptor<Sale>(p => p.Product);
            productHierarchy.AddLevel(p => "All Products", "All Products");
            productHierarchy.AddLevel(p => p.Product.Name, "Product Name");
            flatDataSource.AddHierarchyDescriptor(productHierarchy);

            HierarchyDescriptor<Sale> locationHierarchy = new HierarchyDescriptor<Sale>(p => p.City);
            locationHierarchy.AddLevel(p => "All Location", "All Location");
            locationHierarchy.AddLevel(p => p.City, "Location Name");
            flatDataSource.AddHierarchyDescriptor(locationHierarchy);

            
            CubeMetadata cubeMetadata = new CubeMetadata();
            cubeMetadata.DisplayName = "Sales Data";
            cubeMetadata.DataTypeFullName = typeof(Sale).FullName;
            cubeMetadata.DimensionSettings.Add(new DimensionMetadata()
            {
                SourcePropertyName = "Price",
                DisplayName = "Price",
                DisplayFormat = "{0:C2}"
            });
            cubeMetadata.DimensionSettings.Add(new DimensionMetadata()
            {
                SourcePropertyName = "NumberOfUnits",
                DisplayName = "Number Of Units",
                DisplayFormat = "{0:0.00}"
            });
            cubeMetadata.DimensionSettings.Add(new DimensionMetadata()
            {
                SourcePropertyName = "AmountOfSale",
                DisplayName = "Amount Of Sale",
                DisplayFormat = "{0:C2}"
            });
            
            cubeMetadata.DimensionSettings.Add(new DimensionMetadata()
            {
                SourcePropertyName = "Product",
                DisplayName = "Product"
            });
            cubeMetadata.DimensionSettings.Add(new DimensionMetadata()
            {
                SourcePropertyName = "City",
                DisplayName = "City"
            });
            cubeMetadata.DimensionSettings.Add(new DimensionMetadata()
            {
                SourcePropertyName = "Seller",
                DisplayName = "Seller"
            });
            cubeMetadata.DimensionSettings.Add(new DimensionMetadata()
            {
                SourcePropertyName = "Date",
                DisplayName = "Date"
            });

            flatDataSource.CubesSettings.Add(cubeMetadata);           

            xamPivotGrid1.DataSource = flatDataSource;
            xamPivotDataSelector1.DataSource = flatDataSource;
        }
        
    }
}
