﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Collections;
using System.Globalization;


namespace SampleDataGeneratorNS
{
    internal class SampleDataGenerator
    {
        private static String[] Products;
        private static String[] SellerNames;
        private static String[] Cities;

        private static Random random = new Random();

        public static IEnumerable GenerateSales(int numberOfSales)
        {
            SampleDataGenerator.Products = new String[] { "Accessories", "Bikes", "Clothing", "Components" };
            SampleDataGenerator.SellerNames = new String[] { "John Smith", "Alfredo Fetuchini", "Howard Sprouse", "Russell Shorter", "Nicholas Carmona", "Larry Lieb", "Carl Costello", "Benjamin Dupree", "Bryan Culver", "Monica Freitag", "Lydia Burson", "Harold Garvin", "Walter Pang", "David Haley", "Glenn Landeros", "Harry Tyler", "Stanley Brooker", "Antonio Charbonneau", "Brandon Mckim", "Claudia Kobayashi", "Benjamin Meekins", "Mark Slater", "Kathe Pettel", "Elisa Longbottom" };
            SampleDataGenerator.Cities = new String[] { "Sofia", "London", "New York", "Berlin", "Seattle", "Mellvile", "Tokyo" };

            List<Sale> Sales = new List<Sale>();
            for (double i = 0; i < numberOfSales; i++)
            {
                Sale sale = new Sale();
                sale.Date = GetRandomDate();
                sale.Product = GerRandomProduct();
                sale.NumberOfUnits = GetRandomNumUnits();
                sale.Seller = GetRandomSeller();
                sale.Price = sale.Product.Price;
                sale.AmountOfSale = sale.AmountOfSale;
                Sales.Add(sale);
            }
            return Sales;
        }

        #region Get Random Objects

        private static Seller GetRandomSeller()
        {
            return new Seller()
            {
                City = GetRandomCity(),
                Name = GetRandomSellerName()
            };
        }

        private static string GetRandomSellerName()
        {
            Random a = new Random(SampleDataGenerator.random.Next());
            return SampleDataGenerator.SellerNames[a.Next(SampleDataGenerator.SellerNames.Length)];
        }

        private static string GetRandomCity()
        {
            Random a = new Random(SampleDataGenerator.random.Next());
            return SampleDataGenerator.Cities[a.Next(SampleDataGenerator.Cities.Length)];
        }

        private static int GetRandomNumUnits()
        {
            Random a = new Random(SampleDataGenerator.random.Next());
            return a.Next(1, 500);
        }

        private static Product GerRandomProduct()
        {
            return new Product()
            {
                Name = GetRandomProductName(),
                Price = GetRandomPrice()
            };
        }

        private static double GetRandomPrice()
        {
            Random a = new Random(SampleDataGenerator.random.Next());
            return a.NextDouble() * 100;
        }

        private static string GetRandomProductName()
        {
            Random a = new Random(SampleDataGenerator.random.Next());
            return SampleDataGenerator.Products[a.Next(SampleDataGenerator.Products.Length)];
        }

        private static DateTime GetRandomDate()
        {
            Random a = new Random(SampleDataGenerator.random.Next());
            int day = a.Next(1, 28);
            int month = a.Next(1, 12);
            int year = a.Next(2006, 2010);
            return new DateTime(year, month, day);
        }

        #endregion Get Random Objects
    }

    public class Sale
    {
        public Product Product { get; set; }
        public Seller Seller { get; set; }
        public DateTime Date { get; set; }

        public string City
        {
            get { return Seller.City; }
            set { Seller.City = value; }
        }

        public int NumberOfUnits { get; set; }

        public double AmountOfSale
        {
            get { return Product.Price * NumberOfUnits; }
            set { Product.Price = value / NumberOfUnits; }
        }

        public double Price
        {
            get { return Product.Price; }
            set { Product.Price = value; }
        }
    }

    public class Product
    {
        public string Name { get; set; }
        public double Price { get; set; }
    }

    public class Seller
    {
        public string Name { get; set; }
        public string City { get; set; }
    }
}